← Back to team overview

yade-dev team mailing list archive

[Branch ~yade-dev/yade/trunk] Rev 2097: - Rename of NormalInelasticityLaw into Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity (I a...

 

Merge authors:
  jduriez <jduriez@c1solimara-l>
------------------------------------------------------------
revno: 2097 [merge]
committer: jduriez <jduriez@c1solimara-l>
branch nick: trunk
timestamp: Tue 2010-03-23 15:34:01 +0100
message:
  - Rename of NormalInelasticityLaw into Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity (I accept sincerely any proposal of shorter file names...)
  In fact it is not yet a functor, but I want to try to write it in a more proper way...
  - Corresponding changes in affected files
  - Details in other files
renamed:
  pkg/dem/Engine/GlobalEngine/NormalInelasticityLaw.cpp => pkg/dem/Engine/GlobalEngine/Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity.cpp
  pkg/dem/Engine/GlobalEngine/NormalInelasticityLaw.hpp => pkg/dem/Engine/GlobalEngine/Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity.hpp
modified:
  pkg/dem/DataClass/InteractionPhysics/NormalInelasticityPhys.hpp
  pkg/dem/Engine/Functor/Ip2_2xCohFrictMat_NormalInelasticityPhys.hpp
  pkg/dem/Engine/PartialEngine/Disp2DPropLoadEngine.cpp
  pkg/dem/Engine/PartialEngine/KinemCNDEngine.cpp
  pkg/dem/Engine/PartialEngine/KinemCNLEngine.cpp
  pkg/dem/Engine/PartialEngine/KinemCNLEngine.hpp
  pkg/dem/Engine/PartialEngine/KinemCNSEngine.cpp
  pkg/dem/Engine/PartialEngine/KinemCNSEngine.hpp
  pkg/dem/Engine/PartialEngine/KinemCTDEngine.cpp
  pkg/dem/PreProcessor/SimpleShear.cpp
  py/system.py
  pkg/dem/Engine/GlobalEngine/Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity.cpp
  pkg/dem/Engine/GlobalEngine/Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity.hpp


--
lp:yade
https://code.launchpad.net/~yade-dev/yade/trunk

Your team Yade developers is subscribed to branch lp:yade.
To unsubscribe from this branch go to https://code.launchpad.net/~yade-dev/yade/trunk/+edit-subscription.
=== modified file 'pkg/dem/DataClass/InteractionPhysics/NormalInelasticityPhys.hpp'
--- pkg/dem/Engine/GlobalEngine/NormalInelasticityLaw.cpp	2010-03-20 12:40:44 +0000
+++ pkg/dem/Engine/GlobalEngine/Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity.cpp	2010-03-23 14:19:56 +0000
@@ -6,17 +6,21 @@
 *  GNU General Public License v2 or later. See file LICENSE for details. *
 *************************************************************************/
 
-#include "NormalInelasticityLaw.hpp"
+#include<yade/pkg-dem/Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity.hpp>
+
 #include<yade/pkg-dem/CohesiveFrictionalMat.hpp>
 #include<yade/pkg-dem/ScGeom.hpp>
 #include<yade/pkg-dem/NormalInelasticityPhys.hpp>
 #include<yade/core/Omega.hpp>
 #include<yade/core/Scene.hpp>
 
+YADE_PLUGIN((Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity));
+
+
 Vector3r translation_vect (0.10,0,0);
 
 
-void NormalInelasticityLaw::action()
+void Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity::action()
 {
     shared_ptr<BodyContainer>& bodies = scene->bodies;
 
@@ -289,5 +293,3 @@
 
 }
 
-YADE_PLUGIN((NormalInelasticityLaw));
-

=== renamed file 'pkg/dem/Engine/GlobalEngine/NormalInelasticityLaw.hpp' => 'pkg/dem/Engine/GlobalEngine/Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity.hpp'
--- pkg/dem/Engine/GlobalEngine/NormalInelasticityLaw.hpp	2010-03-20 12:40:44 +0000
+++ pkg/dem/Engine/GlobalEngine/Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity.hpp	2010-03-23 14:19:56 +0000
@@ -8,22 +8,23 @@
 
 #pragma once
 
+// #include<yade/pkg-common/LawFunctor.hpp>
 #include<yade/core/GlobalEngine.hpp>
-
 #include <set>
 #include <boost/tuple/tuple.hpp>
 
-/*! \brief 
-
- */
-
-
-class NormalInelasticityLaw : public GlobalEngine
+
+
+class Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity : public GlobalEngine
 {
-/// Attributes
 	public :
+// <<<<<<< TREE
 		void action();
-	YADE_CLASS_BASE_DOC_ATTRS(NormalInelasticityLaw,
+	YADE_CLASS_BASE_DOC_ATTRS(Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity,
+// =======
+// 		void action();
+// 	YADE_CLASS_BASE_DOC_ATTRS(NormalInelasticityLaw,
+// >>>>>>> MERGE-SOURCE
 				  GlobalEngine,
 				  "Contact law including cohesion, moment transfer and inelastic compression behaviour\n\n This contact Law is inspired by :yref:`CohesiveFrictionalContactLaw` (inspired itselve directly from the work of Plassiard & Belheine, see the corresponding articles in (Annual Report 2006) in http://geo.hmg.inpg.fr/frederic/Discrete_Element_Group_FVD.html for example).\n\n It allows so to set moments, cohesion, tension limit and (that's the difference) inelastic unloadings in compression between bodies. All that concerned brokenBodies (this flag and the erosionactivated one) and the useless 'iter' has been suppressed.\n\n The Relationsships corresponding are Ip2_2xCohFrictMat_NormalInelasticityPhys, where the rigidities, the friction angles (with their tan()), and the orientations of the interactions are calculated. No more cohesion and tension limits are computed for all the interactions.\n\n To use it you should also use :\n- :yref:`CohesiveFrictionalMat` for bodies, with *isCohesive* = 1 (A verifier ce dernier point)\n- :yref:`Ip2_2xCohFrictMat_NormalInelasticityPhys` (=> which involves interactions of :yref:`NormalInelasticityPhys` type)",
 				  ((int,sdecGroupMask,1,"?"))
@@ -33,6 +34,6 @@
 				  );
 };
 
-REGISTER_SERIALIZABLE(NormalInelasticityLaw);
+REGISTER_SERIALIZABLE(Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity);
 
 

=== modified file 'pkg/dem/Engine/PartialEngine/Disp2DPropLoadEngine.cpp'
--- pkg/dem/Engine/PartialEngine/Disp2DPropLoadEngine.cpp	2010-03-20 12:40:44 +0000
+++ pkg/dem/Engine/PartialEngine/Disp2DPropLoadEngine.cpp	2010-03-23 14:19:56 +0000
@@ -14,6 +14,7 @@
 #include <yade/lib-miniWm3/Wm3Math.h>
 
 
+YADE_PLUGIN((Disp2DPropLoadEngine));
 
 void Disp2DPropLoadEngine::postProcessAttributes(bool deserializing)
 {

=== modified file 'pkg/dem/Engine/PartialEngine/KinemCNDEngine.cpp'
--- pkg/dem/Engine/PartialEngine/KinemCNDEngine.cpp	2010-03-20 12:40:44 +0000
+++ pkg/dem/Engine/PartialEngine/KinemCNDEngine.cpp	2010-03-23 14:19:56 +0000
@@ -9,10 +9,10 @@
 #include<yade/core/Scene.hpp>
 #include<yade/lib-base/Math.hpp>
 
-#include"KinemCNDEngine.hpp"
-
-
-
+#include<yade/pkg-dem/KinemCNDEngine.hpp>
+
+
+YADE_PLUGIN((KinemCNDEngine));
 
 void KinemCNDEngine::action(Scene * ncb)
 {

=== modified file 'pkg/dem/Engine/PartialEngine/KinemCNLEngine.cpp'
--- pkg/dem/Engine/PartialEngine/KinemCNLEngine.cpp	2010-03-20 12:40:44 +0000
+++ pkg/dem/Engine/PartialEngine/KinemCNLEngine.cpp	2010-03-23 14:19:56 +0000
@@ -6,7 +6,8 @@
 *  GNU General Public License v2 or later. See file LICENSE for details. *
 *************************************************************************/
 
-#include "KinemCNLEngine.hpp"
+#include<yade/pkg-dem/KinemCNLEngine.hpp>
+
 #include<yade/core/State.hpp>
 #include<yade/pkg-common/Box.hpp>
 #include<yade/pkg-dem/FrictPhys.hpp>
@@ -149,10 +150,10 @@
 			vector<shared_ptr<Engine> >::iterator itLast = ncb->engines.end();
 			for ( ;itFirst!=itLast; ++itFirst )
 			{
-				if ( ( *itFirst )->getClassName() == "NormalInelasticityLaw" ) 
+				if ( ( *itFirst )->getClassName() == "Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity" ) 
 				{
-					if(LOG) cout << "NormalInelasticityLaw engine found" << endl;
-					myLdc =  YADE_PTR_CAST<NormalInelasticityLaw> ( *itFirst );
+					if(LOG) cout << "Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity engine found" << endl;
+					myLdc =  YADE_PTR_CAST<Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity> ( *itFirst );
 					coeff_dech = myLdc ->coeff_dech;
 				}
 			}

=== modified file 'pkg/dem/Engine/PartialEngine/KinemCNLEngine.hpp'
--- pkg/dem/Engine/PartialEngine/KinemCNLEngine.hpp	2010-03-20 12:40:44 +0000
+++ pkg/dem/Engine/PartialEngine/KinemCNLEngine.hpp	2010-03-23 14:19:56 +0000
@@ -12,7 +12,7 @@
 #include<yade/core/PartialEngine.hpp>
 #include<yade/core/Body.hpp>
 #include<yade/lib-base/Math.hpp>
-#include<yade/pkg-dem/NormalInelasticityLaw.hpp>
+#include<yade/pkg-dem/Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity.hpp>
 
 
 
@@ -20,7 +20,7 @@
 class KinemCNLEngine : public PartialEngine
 {
 	private :
-		shared_ptr<NormalInelasticityLaw> myLdc;
+		shared_ptr<Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity> myLdc;
 		Real	alpha	// angle from the lower plate to the left box (trigo wise), the Engine finds itself its value
 			,dalpha	// the increment over alpha, due to vertical displacement of upper box
 			,deltaU	// the vertical increment of displacement to allow on the upper plate on this time step to verify the constant normal stress
@@ -67,7 +67,7 @@
 				 ((Real,wallDamping,0.2,"the vertical displacements done to maintain F equal to F_0 are in fact damped, through this wallDamping"))
 				 ((string,Key,"","string to add at the names of the saved files"))
 				 ((bool,LOG,false,"boolean controling the output of messages on the screen"))
-				 ((Real,coeff_dech,1.0,"in the case of the use of 'NormalInelasticityLaw' for ex, where kn(unload)#kn(load). The engine cares to find the value at the first run")),
+				 ((Real,coeff_dech,1.0,"in the case of the use of 'Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity' for ex, where kn(unload)#kn(load). The engine cares to find the value at the first run")),
 				alpha=Mathr::PI/2.0;
 				temoin=0;
 				 );

=== modified file 'pkg/dem/Engine/PartialEngine/KinemCNSEngine.cpp'
--- pkg/dem/Engine/PartialEngine/KinemCNSEngine.hpp	2010-03-20 12:40:44 +0000
+++ pkg/dem/Engine/PartialEngine/KinemCNSEngine.hpp	2010-03-23 14:19:56 +0000
@@ -12,14 +12,14 @@
 #include<yade/core/PartialEngine.hpp>
 #include<yade/core/Body.hpp>
 #include<yade/lib-base/Math.hpp>
-#include<yade/pkg-dem/NormalInelasticityLaw.hpp>
+#include<yade/pkg-dem/Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity.hpp>
 
 
 
 class KinemCNSEngine : public PartialEngine
 {
 	private :
-		shared_ptr<NormalInelasticityLaw> myLdc;
+		shared_ptr<Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity> myLdc;
 		Real	alpha	// angle from the lower plate to the left box (trigo wise), the Engine finds itself its value
 			,dalpha	// the increment over alpha
 			,deltaH	// the vertical increment of displacement to allow on the upper plate on this time step to verify the normal rigidity
@@ -65,7 +65,7 @@
 		((Real,max_vel,1.0,"to limit the speed of the vertical displacements applied to control upper plate [m/s]"))
 		((string,Key,"","string to add at the names of the saved files"))
 		((bool,LOG,false,"boolean controling the output of messages on the screen"))
-		((Real,coeff_dech,1.0,"in the case of the use of 'NormalInelasticityLaw' for ex, where kn(unload)#kn(load). The engine cares to find the value at the first run"))
+		((Real,coeff_dech,1.0,"in the case of the use of 'Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity' for ex, where kn(unload)#kn(load). The engine cares to find the value at the first run"))
 		((Real,wallDamping,0.2,"the vertical displacements done to maintain F equal to F_0 are in fact damped, through this wallDamping")),
 		alpha=Mathr::PI/2.0;
 		temoin=0;

=== modified file 'pkg/dem/Engine/PartialEngine/KinemCTDEngine.cpp'
--- pkg/dem/Engine/PartialEngine/KinemCTDEngine.cpp	2010-03-20 12:40:44 +0000
+++ pkg/dem/Engine/PartialEngine/KinemCTDEngine.cpp	2010-03-23 14:19:56 +0000
@@ -6,7 +6,7 @@
 *  GNU General Public License v2 or later. See file LICENSE for details. *
 *************************************************************************/
 
-#include"KinemCTDEngine.hpp"
+#include<yade/pkg-dem/KinemCTDEngine.hpp>
 #include<yade/core/State.hpp>
 #include<yade/pkg-common/Box.hpp>
 #include<yade/core/Scene.hpp>

=== modified file 'pkg/dem/PreProcessor/SimpleShear.cpp'
--- pkg/dem/PreProcessor/SimpleShear.cpp	2010-03-16 16:02:55 +0000
+++ pkg/dem/PreProcessor/SimpleShear.cpp	2010-03-23 14:19:56 +0000
@@ -14,7 +14,7 @@
 #include "SimpleShear.hpp"
 
 #include <yade/pkg-dem/CohesiveFrictionalMat.hpp>
-#include <yade/pkg-dem/NormalInelasticityLaw.hpp>
+#include <yade/pkg-dem/Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity.hpp>
 #include <yade/pkg-dem/Ip2_2xCohFrictMat_NormalInelasticityPhys.hpp>
 #include<yade/pkg-dem/GlobalStiffnessTimeStepper.hpp>
 #include <yade/pkg-dem/PositionOrientationRecorder.hpp>
@@ -296,7 +296,7 @@
 	rootBody->engines.push_back(shared_ptr<Engine>(new InsertionSortCollider));
 	rootBody->engines.push_back(interactionGeometryDispatcher);
 	rootBody->engines.push_back(interactionPhysicsDispatcher);
-	rootBody->engines.push_back(shared_ptr<Engine>(new NormalInelasticityLaw));
+	rootBody->engines.push_back(shared_ptr<Engine>(new Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity));
 	if(gravApplied)
 		rootBody->engines.push_back(gravityCondition);
 	if(shearApplied)

=== modified file 'py/system.py'
--- py/system.py	2010-03-22 17:39:33 +0000
+++ py/system.py	2010-03-23 14:19:56 +0000
@@ -125,6 +125,7 @@
 	'CinemDTCEngine':'KinemCTDEngine', # Wed Mar 10 12:34:37 2010, jduriez@c1solimara-l
 	'Ip2_BMP_BMP_CSPhys':'Ip2_2xFrictMat_CSPhys', # Wed Mar 10 15:08:56 2010, eudoxos@frigo
 	'CinemDTCEngine':'KinemCTDEngine', # Tue Mar 16 13:54:21 2010, jduriez@c1solimara-l
+	'NormalInelasticityLaw':'Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity', # Wed Mar 17 15:50:59 2010, jduriez@c1solimara-l
 	### END_RENAMED_CLASSES_LIST ### (do not delete this line; scripts/rename-class.py uses it
 }
--- pkg/dem/DataClass/InteractionPhysics/NormalInelasticityPhys.hpp	2010-02-28 21:21:28 +0000
+++ pkg/dem/DataClass/InteractionPhysics/NormalInelasticityPhys.hpp	2010-03-23 14:19:56 +0000
@@ -10,7 +10,7 @@
 
 #include<yade/pkg-dem/FrictPhys.hpp>
 
 /*! \brief Interaction for using NormalInelasticityLaw
 
 This interaction is similar to CohesiveFrictionalContactInteraction. Among the differences are the unMax, previousun and previousFn (allowing to describe the inelastic unloadings in compression), no more shear and tension Adhesion, no more "fragile", "cohesionBroken" and "cohesionDisablesFriction"
  */
@@ -23,7 +23,7 @@
 		virtual ~NormalInelasticityPhys();
 		void SetBreakingState ();
 	YADE_CLASS_BASE_DOC_ATTRS_CTOR(NormalInelasticityPhys,FrictPhys,
-				 "Physics (of interaction) for using NormalInelasticityLaw",
+				 "Physics (of interaction) for using Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity",
 				 ((Real,unMax,0.0,"the maximum value of penetration depth of the history of this interaction"))
 				 ((Real,previousun,0.0,"the value of this un at the last time step"))
 				 ((Real,previousFn,0.0,"the value of the normal force at the last time step"))
@@ -10,7 +10,7 @@
 #include<yade/pkg-dem/FrictPhys.hpp>
 
-/*! \brief Interaction for using NormalInelasticityLaw
+/*! \brief Interaction for using Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity
 
 This interaction is similar to CohesiveFrictionalContactInteraction. Among the differences are the unMax, previousun and previousFn (allowing to describe the inelastic unloadings in compression), no more shear and tension Adhesion, no more "fragile", "cohesionBroken" and "cohesionDisablesFriction"

=== modified file 'pkg/dem/Engine/Functor/Ip2_2xCohFrictMat_NormalInelasticityPhys.hpp'
--- pkg/dem/Engine/Functor/Ip2_2xCohFrictMat_NormalInelasticityPhys.hpp	2010-02-26 23:29:53 +0000
+++ pkg/dem/Engine/Functor/Ip2_2xCohFrictMat_NormalInelasticityPhys.hpp	2010-03-23 14:19:56 +0000
@@ -10,7 +10,7 @@
 
 #include<yade/pkg-common/InteractionPhysicsFunctor.hpp>
 
 /*! \brief The RelationShips for using NormalInelasticityLaw
 
 In these RelationShips all the attributes of the interactions (which are of NormalInelasticityPhys type) are computed.
 WARNING : as in the others Relationships most of the attributes are computed only once : when the interaction is "new"
@@ -30,7 +30,7 @@
 	FUNCTOR2D(CohesiveFrictionalMat,CohesiveFrictionalMat);
 	YADE_CLASS_BASE_DOC_ATTRS_CTOR(Ip2_2xCohFrictMat_NormalInelasticityPhys,
 				  InteractionPhysicsFunctor,
-				  "The RelationShips for using NormalInelasticityLaw\n\n In these RelationShips all the attributes of the interactions (which are of NormalInelasticityPhys type) are computed. \n\n.. warning::\n\tas in the others :yref:`Ip2 functors<InteractionPhysicsFunctor>`, most of the attributes are computed only once, when the interaction is new.",
+				  "The RelationShips for using Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity\n\n In these RelationShips all the attributes of the interactions (which are of NormalInelasticityPhys type) are computed. \n\n.. warning::\n\tas in the others :yref:`Ip2 functors<InteractionPhysicsFunctor>`, most of the attributes are computed only once, when the interaction is new.",
 				  ((Real,betaR,0.12,"Parameter for computing the torque-stifness : T-stifness = betaR * Rmoy^2"))
 				  ((bool,setCohesionNow,false,""))
 				  ((bool,setCohesionOnNewContacts,false,"")),
@@ -10,7 +10,7 @@
 #include<yade/pkg-common/InteractionPhysicsFunctor.hpp>
 
-/*! \brief The RelationShips for using NormalInelasticityLaw
+/*! \brief The RelationShips for using Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity
 
 In these RelationShips all the attributes of the interactions (which are of NormalInelasticityPhys type) are computed.

=== renamed file 'pkg/dem/Engine/GlobalEngine/NormalInelasticityLaw.cpp' => 'pkg/dem/Engine/GlobalEngine/Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity.cpp'
--- pkg/dem/Engine/PartialEngine/KinemCNSEngine.cpp	2010-03-20 12:40:44 +0000
+++ pkg/dem/Engine/PartialEngine/KinemCNSEngine.cpp	2010-03-23 14:19:56 +0000
@@ -8,7 +8,8 @@
 
 
 
-#include "KinemCNSEngine.hpp"
+#include<yade/pkg-dem/KinemCNSEngine.hpp>
+
 #include<yade/core/State.hpp>
 #include<yade/pkg-common/Box.hpp>
 #include<yade/pkg-dem/FrictPhys.hpp>
@@ -134,11 +135,11 @@
 			vector<shared_ptr<Engine> >::iterator itLast = ncb->engines.end();
 			for ( ;itFirst!=itLast; ++itFirst )
 			{
-				if ( ( *itFirst )->getClassName() == "NormalInelasticityLaw" ) 
+				if ( ( *itFirst )->getClassName() == "Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity" ) 
 				{
-					myLdc =  YADE_PTR_CAST<NormalInelasticityLaw> ( *itFirst );
+					myLdc =  YADE_PTR_CAST<Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity> ( *itFirst );
 					coeff_dech = myLdc ->coeff_dech;
-					if(LOG) cout << "NormalInelasticityLaw engine found, with coeff_dech = " << coeff_dech << endl;
+					if(LOG) cout << "Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity engine found, with coeff_dech = " << coeff_dech << endl;
 				}
 			}
 		}
@@ -164,7 +165,7 @@
 	Real Hcurrent = topbox->state->pos.Y();
 	Real Fdesired = F_0 + KnC * 1.0e9 * Scontact * (Hcurrent-Y0); // The value of the force desired
 
 // Prise en compte de la difference de rigidite entre charge et decharge dans le cadre de NormalInelasticityLaw :
 	if( F_sup.Y() > Fdesired )	// cas ou l'on va monter la plaq <=> (normalemt) a une decharge
 		stiffness *= coeff_dech;
 
@@ -164,7 +165,7 @@
 	Real Fdesired = F_0 + KnC * 1.0e9 * Scontact * (Hcurrent-Y0); // The value of the force desired
 
-// Prise en compte de la difference de rigidite entre charge et decharge dans le cadre de NormalInelasticityLaw :
+// Prise en compte de la difference de rigidite entre charge et decharge dans le cadre de Law2_ScGeom_NormalInelasticityPhys_NormalInelasticity :
 	if( F_sup.Y() > Fdesired )	// cas ou l'on va monter la plaq <=> (normalemt) a une decharge
 		stiffness *= coeff_dech;

=== modified file 'pkg/dem/Engine/PartialEngine/KinemCNSEngine.hpp'